define(["dojo/_base/declare",
        "dojo/_base/lang",
        "dijit/_Widget",        
        "dijit/_TemplatedMixin",
        "dijit/_WidgetsInTemplateMixin",
        "dojo/text!./templates/ImportTypeWizardPage.html",
        "admin/users/dialogs/WizardPage",
        "dojo/string",
        "dojo/dom-style",
        "dojo/i18n!../nls/user_resources",
        "dijit/form/RadioButton",
        "dojox/form/Uploader",
        "dojox/form/uploader/plugins/IFrame",
        "idx/form/TextBox",
        "idx/form/RadioButtonSet",
        "dijit/form/Form"
        ],
        function(dDeclare,
                dLang,
                dWidget,
                dTemplatedMixin,
                dWidgetsInTemplateMixin,
                templateText,
                WizardPage,
                dString,
                domStyle,
                resources) {
	console.log(resources);
return dDeclare("admin.users.dialogs.ImportTypeWizardPage", [dWidget,dTemplatedMixin,dWidgetsInTemplateMixin, WizardPage], {

    /**
     * @private
     */
    baseClass: "ImportTypeWizardPage",


    /**
     * The path to the widget template for the dijit._TemplatedMixin base class.
     * 
     * @private
     * @constant
     * @type String
     */
    templateString: templateText,
    
    /** 
     * Indicate if this widget is also a container
     * @private
     */
    isContainer: false,
    
    /**
     * Indicate if there are widgets in the template
     */
    widgetsInTemplate: true,
    
    /**
     * Page description label
     */
    pageDescription: resources["importTypeDescription"],
    /**
     * Import label
     */
    importTypeLabel: resources["importFromLabel"],
    /**
     * LDAP choice
     */
    ldapStr: resources["ldapServer"],
    /**
     * External file choice
     */
    externalFileStr: resources["externalFile"],
    /**
     * External file label
     */
    externalFileLabel: resources["externalFileLabel"],
    /**
     * Browse button label
     */
    browseButtonLabel: resources["browseButtonLabel"],
    /**
     * Users uploaded from external file
     */
    uploadContent: null,

	/**
	 * Get the title of this page
	 */
	getTitle:function() {
		return "Select Import Source";
	},
	
	/**
	 * Get the description of this page
	 */
	getDescription:function() {
		return this.pageDescription;
	},
	
	/**
	 * Check if this page is complete
	 */
	isComplete:function() {
		if (this.getImportType() == "file") {
			if (this.fileLabelNode.get("value") == "") {
				return false;
			}
		}
		return true;
	},
	
	/**
	 * Prevent the wizard from flipping to the next page if uploadContent is null
	 */
	completePage:function() {
		console.log("completePage");
		if (this.getImportType() == "file" && this.uploadContent == null) {
			return false;
		}
		return true;
	},
	
	/**
	 * Get the import source type
	 */
	getImportType:function() {
		return this.importRBS.get("value");
	},
	
	/**
	 * The startup function
	 */
	startup:function() {
		this.inherited(arguments);
		this.fileNode.set('url', '/optim/rest/security/registry/external');
		this.fileNode.on("change", dLang.hitch(this, "_fileChanged"));
		this.fileNode.on("Complete", dLang.hitch(this, "_uploadComplete"));
		this.fileNode.on("Error", dLang.hitch(this, "_uploadFailed"));
		this.importRBS.on("change", dLang.hitch(this, "_typeChanged"));
		this._typeChanged();
		console.log("startup complete.")
	},
	
	/**
	 * Upload completed
	 */
	_uploadComplete:function(data) {
		console.log("uploadComplete", data);
		this.uploadContent = data;
		this.updateWizardControls();
	},
	
	/**
	 * Upload failed
	 */
	_uploadFailed:function(data) {
		console.log("uploadFailed", data);
	},
	
	/**
	 * File selected for upload
	 */
	_fileChanged:function(data) {
  	  console.log(data);
  	  this.fileLabelNode.set('value', data[0].name);
  	  this.uploadContent = null;
  	  this.updateWizardControls();
    },
    
    /**
     * Import source changed
     */
    _typeChanged:function() {
    	var selected = this.importRBS.get("value");
    	console.log("_typeChanged: " + selected);
    	if (selected == "ldap") {
    		this.fileNode.set('disabled', true);
    	}
    	else {
    		this.fileNode.set('disabled', false);
    	}
    	this.updateWizardControls();
    }
});
});
