<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:optim="http://www.ibm.com/optim/audit/v11.3.0.0"
	xmlns:optimreport="http://www.ibm.com/optim/report/v11.3.0.0"
	xmlns:optimcommon="http://www.ibm.com/optim/common/v11.3.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
	<xsl:import href="CommonTemplates.xsl"/>
	<xsl:output method="html" indent="yes" version="4.0"
		doctype-public="-//W3C//DTD HTML 4.01//EN" doctype-system="http://www.w3.org/TR/html4/strict.dtd" />
	
	<!-- The code here is pulled from early implementations of the report. 					-->
	<!-- This WILL produce a report, but it will not be as robust and polished as Archive. -->
	<xsl:template match="optimreport:CompareReport">
		<xsl:param name="display">True</xsl:param>

		<!--BEGIN SUMMARY SECTION-->
		<xsl:if test="optimreport:summary[@*]">
			<xsl:apply-templates select="optimreport:summary">
				<xsl:with-param name="display" select="$display"/>
			</xsl:apply-templates>
		</xsl:if>
		<!--END SUMMARY SECTION-->
		
		<xsl:call-template name="anchorSetup">
			<xsl:with-param name="name">procdets</xsl:with-param>
		</xsl:call-template>
		
		<!-- Process Details Title Bar -->
		<xsl:call-template name="titleBar">
			<xsl:with-param name="name">Process Details</xsl:with-param>
			<xsl:with-param name="containerId">details_container</xsl:with-param>
			<xsl:with-param name="containerClass">details_container_class</xsl:with-param>
			<xsl:with-param name="anchor">procdets</xsl:with-param>
			<xsl:with-param name="closeByDefault">false</xsl:with-param>
			<xsl:with-param name="isInnerReport">false</xsl:with-param>
		</xsl:call-template>

		<div id="details_container" class="section_container details_container_class" inAllAction="true">
			<xsl:if test="./*/optimreport:compareAccessDefinitionSource/optimreport:localAccessDefinition | ./*/optimreport:compareAccessDefinitionSource/optimreport:accessDefinition | ./*/optimreport:tableMap | ./*/optimreport:localTableMap | ./*/optimreport:columnMap | ./*/optimreport:localColumnMap">
				<table>
					<!-- Call access definition template to determine if we need to display the full section -->
					<xsl:apply-templates select="optimreport:localAccessDefinition"/>
					<xsl:apply-templates select="optimreport:accessDefinition" />

					<!--BEGIN TABLE MAP-->
					<xsl:apply-templates select="./*/optimreport:tableMap">
						<xsl:with-param name="id">compare_tablemap_id</xsl:with-param>
						<xsl:with-param name="classname">compare_tablemap_class</xsl:with-param>
						<xsl:with-param name="arrowid">compare_tablemap_arrow</xsl:with-param>
					</xsl:apply-templates>
					<xsl:apply-templates select="./*/optimreport:localTableMap"/>
					<!--END TABLE MAP-->

					<!--BEGIN COLUMN MAP-->
					<xsl:apply-templates select="./*/optimreport:columnMap">
						<xsl:with-param name="id">compare_columnmap_id</xsl:with-param>
						<xsl:with-param name="classname">compare_columnmap_class</xsl:with-param>
						<xsl:with-param name="arrowid">compare_columnmap_arrow</xsl:with-param>
					</xsl:apply-templates>
					<xsl:apply-templates select="./*/optimreport:localColumnMap"/>
					<!--END COLUMN MAP-->

				</table>
			</xsl:if>
			<div id="compare_sourceFile_block" class="block_gap">
				<table id="compare_source_file_table">
					<tr istitle="yes">
						<td>
							<center>
								<xsl:text>Source 1: </xsl:text>
								<xsl:value-of select="../optimreport:CompareReport/@compareSourceType"/>
							</center>
						</td>
					</tr>
					<tr>
						<td>
							<xsl:value-of select="../optimreport:CompareReport/@compareSourceObjectName"/>
						</td>
					</tr>
				</table>
				<table id="compare_target_file_table">
					<tr istitle="yes">
						<td>
							<center>
								<xsl:text>Source 2: </xsl:text>
								<xsl:value-of select="../optimreport:CompareReport/@compareTargetType"/>
							</center>
						</td>
						<tr>
							<td>
								<xsl:value-of select="../optimreport:CompareReport/@compareTargetObjectName"/>
							</td>
						</tr>
					</tr>
				</table>
				<table id="compare_compare_file_table">
					<!--Compare file-->
					<xsl:apply-templates select="optimreport:compareFile"/>
				</table>
			</div>
			<xsl:call-template name="compareEntities" />
		</div>

		<!-- Request Options Section -->
		<xsl:if test="optimreport:requestOptions/*">
			<xsl:apply-templates select="optimreport:requestOptions">
				<xsl:with-param name="display">False</xsl:with-param>
			</xsl:apply-templates>
		</xsl:if>
		<xsl:for-each select=".//optimreport:extractReport">
			<!-- Set up inner report anchor -->
			<xsl:call-template name="anchorSetup">
				<xsl:with-param name="name">innerreport</xsl:with-param>
			</xsl:call-template>

			<xsl:call-template name="sectionSeperator">
				<xsl:with-param name="sectionName">Extract Report</xsl:with-param>
			</xsl:call-template>
			<xsl:apply-templates select=".">
				<xsl:with-param name="display">
					<xsl:text>False</xsl:text>
				</xsl:with-param>
			</xsl:apply-templates>
		</xsl:for-each>
	</xsl:template>
	<!-- END COMPARE REPORT MAIN -->

	<xsl:template match="optimreport:compareFile">
		<tr istitle="yes">
			<td>
				<center>
					Compare file
				</center>
			</td>
			<td>
				<center>
					Host name
				</center>
			</td>
			<td>
				<center>
					Total size
				</center>
			</td>
		</tr>
		<tr>
			<td>
				<xsl:call-template name="stringCheck">
					<xsl:with-param name="value" select="@name"/>
				</xsl:call-template>
			</td>
			<td>
				<xsl:call-template name="stringCheck">
					<xsl:with-param name="value" select="@hostname"/>
				</xsl:call-template>
			</td>
			<td>
				<xsl:call-template name="fileSizeFormatting">
					<xsl:with-param name="fileSize" select="@totalSizeInBytes"/>
					<xsl:with-param name="start">TB</xsl:with-param>
				</xsl:call-template>
			</td>
		</tr>
	</xsl:template>

	<xsl:template match="optimreport:compareFileSource | optimreport:compareFileTarget | optimreport:compareDatabaseSource | optimreport:compareDatabaseTarget | optimreport:compareAccessDefinitionSource | optimreport:compareAccessDefinitionTarget">
		<xsl:param name="position"/>
		<tr>
			<th>
				<xsl:text>&#160;&#160;&#160;&#160;&#160;</xsl:text>
						Source
						<xsl:value-of select="$position"/>
						type
			</th>
			<td>
				<xsl:choose>
					<xsl:when test="contains(name(.), 'compareFile')">
						<xsl:text>Extract file</xsl:text>
					</xsl:when>
					<xsl:when test="contains(name(.), 'compareAccessDefinition')">
						<xsl:text>Access definition</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>Database</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</td>
		</tr>
		<tr>
			<th>
				<xsl:text>&#160;&#160;&#160;&#160;&#160;</xsl:text>
				Source
				<xsl:value-of select="$position"/>
				 name
			</th>
			<td>
				<xsl:choose>
					<xsl:when test="contains(name(.), 'compareFile')">
						<xsl:value-of select="./@fileName"/>
					</xsl:when>
					<xsl:when test="contains(name(.), 'compareAccessDefinition')">
						<xsl:value-of select="./*[contains(name(.), 'accessDefinition')]/text()"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select=".//optimreport:extractFile/@name"/>
					</xsl:otherwise>
				</xsl:choose>
			</td>
		</tr>
	</xsl:template>
	
	<xsl:template name="compareEntities" >
			<table class="entity_details compare_entity_table">
				<tr istitle="yes">
					<th style="min-width: 125px;">
						<center><xsl:text>Name</xsl:text></center>
					</th>
					<td >
						<center><b><xsl:text>Total Rows</xsl:text></b></center>
					</td>
					<td >
						<center><b><xsl:text>Unmateched</xsl:text></b></center>
					</td>
					<td >
						<center><b><xsl:text>Equal</xsl:text></b></center>
					</td>
					<td >
						<center><b><xsl:text>Different</xsl:text></b></center>
					</td>
					<td >
						<center><b><xsl:text>Duplicate</xsl:text></b></center>
					</td>
				</tr>
				<xsl:for-each select="optimreport:entity">
						<tr>
							<th class="indent">
								<xsl:value-of select="@name" />
							</th>
							<td>
								<xsl:call-template name="numberFormat">
									<xsl:with-param name="number" select="@recordCount"/>
									<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
								</xsl:call-template>
							</td>
							<td>
								<xsl:call-template name="numberFormat">
									<xsl:with-param name="number" select="@unmatched"/>
									<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
								</xsl:call-template>
							</td>
							<td>
								<xsl:call-template name="numberFormat">
									<xsl:with-param name="number" select="@equal"/>
									<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
								</xsl:call-template>
							</td>
							<td>
								<xsl:call-template name="numberFormat">
									<xsl:with-param name="number" select="@different"/>
									<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
								</xsl:call-template>
							</td>
							<td>
								<xsl:call-template name="numberFormat">
									<xsl:with-param name="number" select="@duplicate"/>
									<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
								</xsl:call-template>
							</td>
						</tr>
					<xsl:if test="(position() mod 2) = 0 and not(position() = last())">
						<tr class="hiddenRow">
							<td colspan="6"></td>
						</tr>
					</xsl:if>
				</xsl:for-each>

			</table>
		</xsl:template>
	<!-- END entities section -->
	
</xsl:stylesheet>

