<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:optim="http://www.ibm.com/optim/audit/v11.3.0.0"
	xmlns:optimreport="http://www.ibm.com/optim/report/v11.3.0.0"
	xmlns:optimcommon="http://www.ibm.com/optim/common/v11.3.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
	<xsl:import href="CommonTemplates.xsl"/>
	<xsl:import href="ReportSummary.xsl"/>

	<xsl:key name="privilegeGroup" match="privilegeRoleState" use="concat(../@userGroup, '+', @privilegeClass)"/>
	<xsl:output method="html" indent="yes" version="4.0"
		doctype-public="-//W3C//DTD HTML 4.01//EN" doctype-system="http://www.w3.org/TR/html4/strict.dtd" />
	<xsl:key name="groups" match="optimreport:processDetails/optimreport:privilegeRoleState" use="@userGroup" />
	
	<xsl:template match="optimreport:ReportProcessReport">
		<!--BEGIN SUMMARY SECTION-->
		<xsl:apply-templates select="optimreport:summary[@*] | optimreport:archiveFileReport | optimreport:compareFileReport | optimreport:securityReport | optimreport:archiveDirectoryReport" />
		
		<!--END SUMMARY SECTION-->
		<xsl:call-template name="anchorSetup">
			<xsl:with-param name="name">procdets</xsl:with-param>
		</xsl:call-template>
		
		<!-- Process Details Title Bar -->
		<xsl:call-template name="titleBar">
			<xsl:with-param name="name">Process Details</xsl:with-param>
			<xsl:with-param name="containerId">details_container</xsl:with-param>
			<xsl:with-param name="containerClass">details_container_class</xsl:with-param>
			<xsl:with-param name="anchor">procdets</xsl:with-param>
			<xsl:with-param name="closeByDefault">false</xsl:with-param>
			<xsl:with-param name="isInnerReport">false</xsl:with-param>
		</xsl:call-template>
		
		
		<!-- Process Details Container -->
		<div id="details_container" class="section_container details_container_class" inAllAction="true">
			<xsl:choose>
				<xsl:when test="contains(name(./*/*), 'objectReport')">
					<xsl:call-template name="object_details"/>
				</xsl:when>
				<xsl:when test="contains(name(./*/*), 'functionReport')">
					<xsl:call-template name="function_details"/>
				</xsl:when>
				<xsl:when test="contains(name(./*/*), 'userReport')">
					<xsl:call-template name="user_details"/>
				</xsl:when>
				<xsl:when test="./optimreport:archiveDirectoryReport">
					<xsl:call-template name="directory_details"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="other_details"/>
				</xsl:otherwise>
			</xsl:choose>
			
		</div>
		
		<!-- Request Options Section -->
		<xsl:if test="optimreport:requestOptions/*">
			<xsl:apply-templates select="optimreport:requestOptions">
				<xsl:with-param name="display">False</xsl:with-param>
			</xsl:apply-templates>
		</xsl:if>
	</xsl:template>

	<xsl:template name="directory_details">
		<xsl:variable name="number_criteria" select="count(.//optimreport:archiveCriteria/optimreport:criteria)"/>
			<xsl:choose>
				<xsl:when test="count(optimreport:archiveDirectoryReport/optimreport:detail[1]/optimreport:entry) &gt; 8">
					<xsl:for-each select=".//optimreport:detail">
					<xsl:variable name="num" select="count(./optimreport:entry)"/>
					<xsl:variable name="id" select="generate-id(.)"/>
					<table>
						<xsl:choose>
							<xsl:when test="position()=1">
								<xsl:attribute name="class">directory_headers</xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="class">directory_headers block_gap</xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
						<tr>
							<td colspan="2" class="directory_name  drop_down_hover" istitle="yes" onClick="toggleById('{$id}', event); swap('{$id}DetailsArrow','{$id}', event)">

								<!-- Javascript controls to expand and collapse the section -->
								<a id="JSLanding{$id}" />

								<xsl:call-template name="arrow">
									<xsl:with-param name="id" select="concat($id,'DetailsArrow')" />
									<xsl:with-param name="isExpand">false</xsl:with-param>
								</xsl:call-template>
								<!-- End of Javascript controls -->
								<span class="second_indent">
									<xsl:text>Entry: </xsl:text>
									<xsl:value-of select="position()"/>
								</span>
							</td>
							<td>
								<xsl:call-template name="stringCheck">
									<xsl:with-param name="value" select="./*[@name='File name']/@value"/>
								</xsl:call-template>
							</td>
						</tr>
					</table>

					<div id="{$id}" class="statistic_table_content_block {$id} block_gap" style="display:none;" inAllAction="true">
						<table class="statistic_table">
								<tr>
									<xsl:for-each select="optimreport:entry[position() &lt;= ceiling($num div 2) and (./@name != 'File name')]">
											<th>
												<center>
													<xsl:call-template name="stringCheck">
														<xsl:with-param name="value" select="@name"/>
													</xsl:call-template>
												</center>
											</th>
									</xsl:for-each>
								</tr>
								<tr>
									<xsl:for-each select="optimreport:entry[position() &lt;= ceiling($num div 2) and (./@name != 'File name')]">
										<td>
											<center>
												<xsl:call-template name="stringCheck">
													<xsl:with-param name="value" select="@value"/>
												</xsl:call-template>
											</center>
										</td>
									</xsl:for-each>
								</tr>
						</table>

						<table class="statistic_table block_gap">
							<tr>
								<xsl:for-each select="optimreport:entry[position() &gt; ceiling($num div 2) and (./@name != 'File name')]">
									<th>
										<center>
											<xsl:call-template name="stringCheck">
												<xsl:with-param name="value" select="@name"/>
											</xsl:call-template>
										</center>
									</th>
								</xsl:for-each>
							</tr>
							<tr>
								<xsl:for-each select="optimreport:entry[position() &gt; ceiling($num div 2) and (./@name != 'File name')]">
									<td>
										<center>
											<xsl:call-template name="stringCheck">
												<xsl:with-param name="value" select="@value"/>
											</xsl:call-template>
										</center>
									</td>
								</xsl:for-each>
							</tr>
						</table>
					</div>
					</xsl:for-each>
				</xsl:when>
				<xsl:otherwise>
					<table class="statistic_table">
						<xsl:for-each select=".//optimreport:detail[1]">
							<tr>
								<xsl:for-each select="optimreport:entry">
									<th>
										<center>
											<xsl:call-template name="stringCheck">
												<xsl:with-param name="value" select="@name"/>
											</xsl:call-template>
										</center>
									</th>
								</xsl:for-each>
							</tr>
						</xsl:for-each>
						<xsl:for-each select=".//optimreport:detail">
							<tr>
								<xsl:for-each select="optimreport:entry">
									<td>
										<center>
											<xsl:call-template name="stringCheck">
												<xsl:with-param name="value" select="@value"/>
											</xsl:call-template>
										</center>
									</td>
								</xsl:for-each>
							</tr>
						</xsl:for-each>
					</table>
				</xsl:otherwise>
			</xsl:choose>
	</xsl:template>

	<xsl:template name="object_details">
		<table class="object_security_details_table ">
			<xsl:for-each select="./*/*/optimreport:objectSecurityDetail">
				
				<xsl:variable name="anchor">
					<xsl:call-template name="substring-before-last">
						<xsl:with-param name="list" select="@name"/>
						<xsl:with-param name="delimiter" select="':'"/>
					</xsl:call-template>
				</xsl:variable>
				<a name="{$anchor}"/>
				<xsl:variable name="id" select="generate-id(@name)"/>
				<table>
					<xsl:choose>
						<xsl:when test="position()=1">
							<xsl:attribute name="class">object_security_headers</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="class">object_security_headers block_gap</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<tr>
						<xsl:choose>
							<xsl:when test="*">
								<td colspan="2" class="object_security_name  drop_down_hover" istitle="yes" onClick="toggleById('{$id}', event); swap('{$id}DetailsArrow','{$id}', event)">

									<!-- Javascript controls to expand and collapse the section -->
									<a id="JSLanding{$id}" />

									<xsl:call-template name="arrow">
										<xsl:with-param name="id" select="concat($id,'DetailsArrow')" />
										<xsl:with-param name="isExpand">false</xsl:with-param>
									</xsl:call-template>
									<!-- End of Javascript controls -->
									<span class="second_indent">
										<xsl:value-of select="@name"/>
									</span>
								</td>
							</xsl:when>
							<xsl:otherwise>
								<td colspan="2" istitle="yes">
									<xsl:value-of select="@name"/>
								</td>
							</xsl:otherwise>
						</xsl:choose>
					</tr>
				</table>

				<div id="{$id}" class="statistic_table_content_block {$id} block_gap" style="display:none;" inAllAction="true">
					<table class="object_security_body">
						<tr istitle="yes">
							<td colspan="2">
								<center>
									Owner:
									<xsl:value-of select="@owner"/>
								</center>
							</td>
							<td colspan="4">
								<center>
									Object Access
								</center>
							</td>
							<td colspan="5">
								<center>
									ACL Access
								</center>
							</td>
						</tr>
						<tr istitle="yes">
							<td>
								<center>
									User / Group
								</center>
							</td>
							<td>
								<center>
									Role
								</center>
							</td>
							<td>
								<center>
									Read
								</center>
							</td>
							<td>
								<center>
									Update
								</center>
							</td>
							<td>
								<center>
									Delete
								</center>
							</td>
							<td>
								<center>
									Execute
								</center>
							</td>
							<td>
								<center>
									Read
								</center>
							</td>
							<td>
								<center>
									Update
								</center>
							</td>
							<td>
								<center>
									Delete
								</center>
							</td>
						</tr>
						<xsl:for-each select="./optimreport:detailItem">
							<tr>
								<td>
									<xsl:call-template name="stringCheck">
										<xsl:with-param name="value" select="@userGroup"/>
									</xsl:call-template>
								</td>
								<td>
									<xsl:call-template name="stringCheck">
										<xsl:with-param name="value" select="@role"/>
									</xsl:call-template>
								</td>
								<td>
									<xsl:call-template name="stringCheck">
										<xsl:with-param name="value" select="./optimreport:objectAccess/@readAccess"/>
									</xsl:call-template>
								</td>
								<td>
									<xsl:call-template name="stringCheck">
										<xsl:with-param name="value" select="./optimreport:objectAccess/@updateAccess"/>
									</xsl:call-template>
								</td>
								<td>
									<xsl:call-template name="stringCheck">
										<xsl:with-param name="value" select="./optimreport:objectAccess/@deleteAccess"/>
									</xsl:call-template>
								</td>
								<td>
									<xsl:call-template name="stringCheck">
										<xsl:with-param name="value" select="./optimreport:objectAccess/@executeAccess"/>
									</xsl:call-template>
								</td>
								<td>
									<xsl:call-template name="stringCheck">
										<xsl:with-param name="value" select="./optimreport:aclAccess/@readAccess"/>
									</xsl:call-template>
								</td>
								<td>
									<xsl:call-template name="stringCheck">
										<xsl:with-param name="value" select="./optimreport:aclAccess/@updateAccess"/>
									</xsl:call-template>
								</td>
								<td>
									<xsl:call-template name="stringCheck">
										<xsl:with-param name="value" select="./optimreport:aclAccess/@deleteAccess"/>
									</xsl:call-template>
								</td>
							</tr>
						</xsl:for-each>
					</table>
				</div>
			</xsl:for-each>
		</table>
		
		<!-- ACD TABLE -->
		<xsl:if test="./*/*/optimreport:acd">
			<table class="block_gap">
				<tr istitle="yes">
					<td>
						<center>
							Name
						</center>
					</td>
					<td>
						<center>
							Description
						</center>
					</td>
				</tr>
				<xsl:for-each select="./*/*/optimreport:acd">
					<tr>
						<td>
							<xsl:call-template name="stringCheck">
								<xsl:with-param name="value" select="@name"/>
							</xsl:call-template>
						</td>
						<td>
							<xsl:call-template name="stringCheck">
								<xsl:with-param name="value" select="@value"/>
							</xsl:call-template>
						</td>
					</tr>
				</xsl:for-each>
			</table>
		</xsl:if>
	</xsl:template>

	<xsl:template name="function_details">
		<div class="object_security_details_table ">
			<xsl:for-each select=".//optimreport:functionReport/optimreport:privilegeCriteria[not(@privilegeClass = preceding-sibling::optimreport:privilegeCriteria/@privilegeClass)]">
				<xsl:variable name="anchor" select="generate-id(.)"/>
				<a name="{$anchor}"/>
				<table class="function_security_headers">
					<xsl:if test="position()!=1">
						<xsl:attribute name="class">function_security_headers block_gap</xsl:attribute>
					</xsl:if>
					<tr>
						<td colspan="2" class="function_security_name  drop_down_hover" istitle="yes" onClick="toggleById('{$anchor}', event); swap('{$anchor}DetailsArrow','{$anchor}', event)">

							<!-- Javascript controls to expand and collapse the section -->

							<xsl:call-template name="arrow">
								<xsl:with-param name="id" select="concat($anchor,'DetailsArrow')" />
								<xsl:with-param name="isExpand">false</xsl:with-param>
							</xsl:call-template>
							<!-- End of Javascript controls -->
							<span class="second_indent">
							<xsl:value-of select="@privilegeClass"/>
							</span>
						</td>
					</tr>
				</table>
				<xsl:variable name="target" select =".//optimreport:privilege/text()"/>
				<xsl:variable name="class" select="@privilegeClass"/>
				<table id="{$anchor}" class="statistic_table_content_block {$anchor} block_gap" style="display:none" inAllAction="true">
					<tr istitle="yes">
						<td>
							<center>
								Privilege
							</center>
						</td>
						<td>
							<center>
								User / Group
							</center>
						</td>
						<td>
							<center>
								Role
							</center>
						</td>
						<td>
							<center>
								State
							</center>
						</td>
					</tr>
					<xsl:for-each select="..//optimreport:privilegeDetails[@privilegeCriteria = $class]">
						<xsl:variable name="actionId" select="generate-id(.)"/>
						<xsl:variable name="detailCount" select="count(optimreport:detail)"/>
						<xsl:for-each select="optimreport:detail">
						<tr>
							<xsl:choose>
								<xsl:when test="position()!=1">
									<xsl:attribute name="inallaction">true</xsl:attribute>
									<xsl:attribute name="style">display:none</xsl:attribute>
									<xsl:attribute name="class">
										<xsl:value-of select="$actionId"/>
									</xsl:attribute>
								</xsl:when>
								<xsl:otherwise>
									<xsl:attribute name="style">display:''</xsl:attribute>
									<xsl:attribute name="swaparrow">true</xsl:attribute>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:choose>
								<xsl:when test="position()!=1">
									<td class="emptyCell {$actionId}" style="display:none" inallaction="true"></td>
								</xsl:when>
								<xsl:otherwise>
									<xsl:choose>
										<xsl:when test="$detailCount &gt; 1">
											<th class="category_title drop_down_hover" onClick="toggleRows('{$actionId}', event); SwapByClass('blockArrow', '{$actionId}', event)">
												<xsl:call-template name="arrow">
													<xsl:with-param name="id" select="concat($actionId, '_arrow')"/>
													<xsl:with-param name="isExpand">false</xsl:with-param>
												</xsl:call-template>
												<xsl:text>&#160;&#160;&#160;</xsl:text>
												<xsl:value-of select="../@privilegeTarget"/>
											</th>
										</xsl:when>
										<xsl:otherwise>
											<th>
												<xsl:value-of select="../@privilegeTarget"/>
											</th>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:otherwise>
							</xsl:choose>
							<td>
								<xsl:value-of select="@userGroup"/>
							</td>
							<td>
								<xsl:value-of select="@role"/>
							</td>
							<td>
								<xsl:value-of select="optimreport:state/text()"/>
							</td>
						</tr>
						</xsl:for-each>
					</xsl:for-each>
				</table>
			</xsl:for-each>
		</div>
	</xsl:template>

	<!--User detail section-->
	<xsl:template name="user_details">
		<xsl:for-each select="./optimreport:securityReport/optimreport:userReport/optimreport:processDetails">
			<xsl:call-template name="securityTemplateDetails">
				<xsl:with-param name="node" select="."/>
				<xsl:with-param name="anchorNode" select="../optimreport:userGroup"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="other_details">
		<table class="report_process_details">
			<tr>
				<th class="second_indent">
						Source file
				</th>
				<td>
					<xsl:call-template name="stringCheck">
						<xsl:with-param name="value" select=".//*/@fileName"/>
					</xsl:call-template>
				</td>
			</tr>
			<tr>
				<th class="second_indent">
						Output type
				</th>
				<td>
					<xsl:call-template name="stringCheck">
						<xsl:with-param name="value" select="./@runType"/>
					</xsl:call-template>
				</td>
			</tr>
			<tr>
				<th class="second_indent">
						Report file
				</th>
				<td>
					<xsl:call-template name="stringCheck">
						<xsl:with-param name="value" select="./@reportFile"/>
					</xsl:call-template>
				</td>
			</tr>
		</table>

		<xsl:choose>
			<xsl:when test="./optimreport:compareFileReport">
				<xsl:call-template name="reportCompareEntities"/>
			</xsl:when>
			<xsl:otherwise>
				<table class="entity_details">
					<xsl:for-each select=".//optimreport:entities/optimreport:entity">
						<tr>
							<th>
								<xsl:call-template name="stringCheck">
									<xsl:with-param name="value" select="@name"/>
								</xsl:call-template>
							</th>
							<td class="rightAlignRow">
								<xsl:call-template name="numberFormat">
									<xsl:with-param name="number" select="@recordCount"/>
									<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
								</xsl:call-template>
							</td>
						</tr>
					</xsl:for-each>
				</table>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="reportCompareEntities">
		<table class="entity_details report_compare_entity_table noBorder">
			<tr istitle="yes">
				<th style="min-width: 125px;">
				</th>
				<td >
					<center>
						<b>
							<xsl:text>Total Rows</xsl:text>
						</b>
					</center>
				</td>
				<td >
					<center>
						<b>
							<xsl:text>Unmatched</xsl:text>
						</b>
					</center>
				</td>
				<td >
					<center>
						<b>
							<xsl:text>Equal</xsl:text>
						</b>
					</center>
				</td>
				<td >
					<center>
						<b>
							<xsl:text>Different</xsl:text>
						</b>
					</center>
				</td>
				<td >
					<center>
						<b>
							<xsl:text>Duplicate</xsl:text>
						</b>
					</center>
				</td>
			</tr>
			<xsl:for-each select=".//optimreport:entity">
				<tr>
					<th class="indent">
						<xsl:value-of select="@name" />
					</th>
					<td class="rightAlignRow">
						<xsl:call-template name="numberFormat">
							<xsl:with-param name="number" select="@recordCount"/>
							<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
						</xsl:call-template>
					</td>
					<td class="rightAlignRow">
						<xsl:call-template name="numberFormat">
							<xsl:with-param name="number" select="@unmatched"/>
							<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
						</xsl:call-template>
					</td>
					<td class="rightAlignRow">
						<xsl:call-template name="numberFormat">
							<xsl:with-param name="number" select="@equal"/>
							<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
						</xsl:call-template>
					</td>
					<td class="rightAlignRow">
						<xsl:call-template name="numberFormat">
							<xsl:with-param name="number" select="@different"/>
							<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
						</xsl:call-template>
					</td>
					<td class="rightAlignRow">
						<xsl:call-template name="numberFormat">
							<xsl:with-param name="number" select="@duplicate"/>
							<xsl:with-param name="digitsAfterPoint">0</xsl:with-param>
						</xsl:call-template>
					</td>
				</tr>
				<xsl:if test="(position() mod 2) = 0 and not(position() = last())">
					<tr class="hiddenRow">
						<td colspan="6"></td>
					</tr>
				</xsl:if>
			</xsl:for-each>

		</table>
	</xsl:template>

	<xsl:template name="securityTemplateDetails">
		<xsl:param name="node"/>
		<xsl:param name="anchorNode"/>

		<xsl:for-each select="$node">
			<xsl:variable name="nodeName" select="@userGroup"/>
			<!-- Set up anchor -->
			<xsl:variable name="anchor">
				<xsl:for-each select="$anchorNode">
					<xsl:if test="translate(text(), $smallcase, $uppercase)=translate($nodeName, $smallcase, $uppercase)">
						<xsl:value-of select="generate-id(.)"/>
					</xsl:if>
				</xsl:for-each>
			</xsl:variable>

			<xsl:variable name="blockClass">
				<xsl:choose>
					<xsl:when test="string-length($anchor) = 0">
						<xsl:value-of select="generate-id(.)"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$anchor"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			
			<!-- Set up table title -->
			<a name="{$anchor}"/>
			<table class="user_security_headers">
				<xsl:if test="position()!=1">
					<xsl:attribute name="class">user_security_headers block_gap</xsl:attribute>
				</xsl:if>
				<tr>
					<td colspan="2" class="object_security_name  drop_down_hover" istitle="yes" onClick="toggleById('{$blockClass}', event); swap('{$blockClass}DetailsArrow','{$blockClass}', event)">
						<xsl:call-template name="arrow">
							<xsl:with-param name="id" select="concat($blockClass,'DetailsArrow')" />
							<xsl:with-param name="isExpand">false</xsl:with-param>
						</xsl:call-template>
						<!-- End of Javascript controls -->
						<span class="second_indent">
							<xsl:value-of select="@userGroup"/>
						</span>
					</td>
				</tr>
			</table>

			<table id="{$blockClass}" class="statistic_table_content_block {$blockClass} block_gap" style="display:none" inAllAction="true">
				<tr istitle="yes">
					<td>
						<center>
							Privilege
						</center>
					</td>
					<td>
						<center>
							Role
						</center>
					</td>
					<td>
						<center>
							State
						</center>
					</td>
				</tr>
				<xsl:for-each select="optimreport:privilegeRoleState[not(@privilegeClass = preceding-sibling::optimreport:privilegeRoleState/@privilegeClass)]">
					<xsl:variable name="currentClass" select="@privilegeClass"/>
					<xsl:variable name="privilegeClass" select="generate-id(.)"/>
					<tr swaparrow="true" istitle="yes">
						<td colspan="3" class="privilegeClass_name  drop_down_hover" istitle="yes" onClick="toggleRows('{$privilegeClass}', event); swap('{$privilegeClass}DetailsArrow','{$privilegeClass}', event)">
							<xsl:call-template name="arrow">
								<xsl:with-param name="id" select="concat($privilegeClass,'DetailsArrow')" />
								<xsl:with-param name="isExpand">false</xsl:with-param>
							</xsl:call-template>
							<!-- End of Javascript controls -->
							<span class="second_indent">
								<xsl:value-of select="@privilegeClass"/>
							</span>
						</td>
					</tr>
					<xsl:for-each select="../optimreport:privilegeRoleState[@privilegeClass = $currentClass]">
						<tr id="{$privilegeClass}" class="{$privilegeClass}" style="display:none" inallaction="true">
							<td>
								<xsl:value-of select="optimreport:privilege/text()"/>
							</td>
							<td>
								<xsl:value-of select="optimreport:role/text()"/>
							</td>
							<td>
								<xsl:value-of select="optimreport:state/text()"/>
							</td>
						</tr>
					</xsl:for-each>
				</xsl:for-each>
			</table>
		</xsl:for-each>
	</xsl:template>
	
</xsl:stylesheet>